<?php

namespace Drupal\martelus_companion\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class MartelusCompanionForm.
 */
class MartelusCompanionForm extends ConfigFormBase {

  /**
   * GuzzleHttp\ClientInterface definition.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->httpClient = $container->get('http_client');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'martelus_companion.settings'
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'martelus_companion_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('martelus_companion.settings');
    $form['markup1'] = [
      '#type' => 'markup',
      '#markup' => '
        <div class="btn-group">
          <a href="https://martelus.store/plans-and-pricing" target="_blank" class="btn-martelus-store">Don\'t have an account? Create one now!</a>
        </div>
        <p class="welcome-message">
          The Martelus Companion interacts with users according to instructions you provide in the prompt on your Martelus account dashboard. Users will be able to speak with the bot in either voice or text mode.<br>
To get started, you need to enter your Martelus Account ID. You can find your account id under settings on your Martelus account dashboard.
        </p>
      '
    ];

    $form['accountid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Account ID'),
      '#placeholder' => '266626f8-f175-447f-9683-c386b3ef9d2b ',
      '#description' => $this->t('Use your account ID to enable your bot.'),
      '#default_value' => $config->get('accountid'),
    ];

    $form['markup6'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      '
    ];
    $form['markup7'] = [
      '#type' => 'markup',
      '#markup' => '
        </div>
      '
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('martelus_companion.settings')
      ->set('accountid', $form_state->getValue('accountid'))
      ->save();
    \Drupal::service('cache.render')->invalidateAll();
  }

}


